# -*- coding: utf-8 -*-
"""
helper module for acomea.mailup
"""

import base64
import requests

from django.conf import settings
from django.http import HttpResponse

class MailupClient():

    def __init__(self):
        self.logonEndpoint = "https://services.mailup.com/Authorization/OAuth/LogOn"
        self.authorizationEndpoint = "https://services.mailup.com/Authorization/OAuth/Authorization"
        self.tokenEndpoint = "https://services.mailup.com/Authorization/OAuth/Token"
        self.consoleEndpoint = "https://services.mailup.com/API/v1.1/Rest/ConsoleService.svc"
        self.mailstatisticsEndpoint = "https://services.mailup.com/API/v1.1/Rest/MailStatisticsService.svc"
        self.response = HttpResponse()

        self.clientId = settings.ACOMEA_MAILUP_CLIENT_ID
        self.clientSecret = settings.ACOMEA_MAILUP_SECRET
        self.accessToken = None
        self.refreshToken = None

    def retrieve_access_token(self):
        params = {
            "grant_type": "password",
            "client_id": self.clientId,
            "client_secret": self.clientSecret,
            "username": settings.ACOMEA_MAILUP_USERNAME,
            "password": settings.ACOMEA_MAILUP_PASSWORD,
        }
        headers = {
            'content-type': 'application/x-www-form-urlencoded',
            'Authorization': "Basic %s" % base64.b64encode(self.clientId+":"+self.clientSecret)
        }
        r = requests.post(self.tokenEndpoint, params=params, headers=headers)
        ret = r.json()
        self.accessToken = ret["access_token"]
        self.refreshToken = ret["refresh_token"]
        self.save_token()

    def refresh_token(self):
        params = {
            "grant_type": "refresh_token",
            "client_id": self.clientId,
            "client_secret": self.clientSecret,
            "refresh_token": self.refreshToken,
        }
        headers = {
            'content-type': 'application/x-www-form-urlencoded',
        }
        r = requests.post(self.tokenEndpoint, params=params, headers=headers)
        ret = r.json()
        self.accessToken = ret["access_token"]
        self.refreshToken = ret["refresh_token"]

    def save_token(self):
        max_age = 60*60*24
        self.response.set_cookie("access_token", self.accessToken, max_age=max_age)
        self.response.set_cookie("refresh_token", self.refreshToken, max_age=max_age)

    def read_lists(self):
        params = {
            "token": self.accessToken,
            "format": "json",
        }
        cookies = {"access_token": self.accessToken, "refresh_token": self.refreshToken}
        ret = requests.get("https://services.mailup.com/API/v1.1/Rest/ConsoleService.svc/Console/User/Lists", cookies=cookies)
        print ret.text
        # if ret.status_code == 401:
        #     self.refresh_token()
        #     self.read_lists()
